CLI reference
=============




.. sphinx_argparse_cli::
   :module: xemc3.cli.append_time
   :func: parser
   :prog: xemc3-append-time



.. sphinx_argparse_cli::
   :module: xemc3.cli.to_netcdf
   :func: parser
   :prog: xemc3-to-netcdf



.. sphinx_argparse_cli::
   :module: xemc3.cli.xdivertor
   :func: parser
   :prog: xemc3-divertor



.. sphinx_argparse_cli::
   :module: xemc3.cli.to_archive
   :func: parser
   :prog: xemc3-to-archive

